context("dams")

test_that("dams works", {
  expect_equal(ncol(nid_subset), 32)
})
